import { Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { JSONUtils, BaseUIComponent, propDescription, PropTypes, BindingProperties, PropertyCategories, StyleProperties, CoreService, toXMLResult, DynamicComponentsCoreModule } from '@ngx-dynamic-components/core';
import { NgSelectModule } from '@ng-select/ng-select';
import { setTheme } from 'ngx-bootstrap/utils';
import { TabsModule } from 'ngx-bootstrap/tabs';
import { __extends, __decorate, __metadata, __read } from 'tslib';

var packageName = 'bootstrap';

var example1 = {
    uiModel: "\n    <div class=\"flex-column\">\n      <div class=\"form-group\">\n        <label class=\"col-form-label\" width=\"60px\">Select Option</label>\n        <ng-select width=\"300px\" binding=\"$.selectedOption\">\n          <option value=\"o1\">Option 1</option>\n          <option value=\"o2\">Option 2</option>\n        </ng-select>\n      </div>\n    </div>\n  ",
    dataModel: {},
    title: 'Static dropdown declaration',
};
var example2 = {
    uiModel: "\n    <div class=\"flex-column\">\n      <div class=\"form-group\">\n        <label class=\"col-form-label\" width=\"60px\">Select</label>\n        <ng-select width=\"300px\" itemsSource=\"$.list\" binding=\"$.selected\"></ng-select>\n      </div>\n    </div>\n  ",
    dataModel: {
        list: [{ label: 'Data 1', value: 'd1' }, { label: 'Data 2', value: 'd2' }]
    },
    title: 'Dropdown options binded to dataModel',
};
var example3 = {
    uiModel: "\n    <div class=\"flex-column\">\n      <div class=\"form-group\">\n        <label class=\"col-form-label\" width=\"60px\">Country</label>\n        <ng-select onSelect=\"countryChanged\" width=\"300px\" binding=\"$.country\">\n          <option value=\"uk\">United Kingdom</option>\n          <option value=\"ua\">Ukraine</option>\n        </ng-select>\n      </div>\n      <div class=\"form-group\">\n        <label class=\"col-form-label\" width=\"60px\">City</label>\n        <ng-select width=\"300px\" itemsSource=\"$.cities\" binding=\"$.city\"></ng-select>\n      </div>\n    </div>\n  ",
    dataModel: {},
    scripts: "\n  def countryChanged():\n    dataModel.city = null\n    if dataModel.country == null:\n      dataModel.cities = []\n    if dataModel.country == \"uk\":\n      dataModel.cities = [{label: \"London\", value: \"lon\"}, {label: \"Liverpool\", value: \"liv\"}]\n    if dataModel.country == \"ua\":\n      dataModel.cities = [{label: \"Kyiv\", value: \"kyiv\"}, {label: \"Lviv\", value: \"lvi\"}]\n  ",
    title: 'Dependency between dropdowns',
    description: 'Handles change event from first dropdown and changes values in second.'
};
var example = [example1, example1, example2];

var SelectComponent = /** @class */ (function (_super) {
    __extends(SelectComponent, _super);
    function SelectComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SelectComponent.prototype.onSelect = function () {
        this.changedDataModel.emit(this.dataModel);
        // onSelect - deprecated.
        this.emitEvent(this.properties.onSelect);
        this.emitEvent(this.properties.change);
    };
    SelectComponent.prototype.emitEvent = function (prop, param) {
        _super.prototype.emitEvent.call(this, prop, param);
    };
    Object.defineProperty(SelectComponent.prototype, "selectStyles", {
        get: function () {
            if (this.properties.selectHeight) {
                return {
                    height: this.properties.selectHeight
                };
            }
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SelectComponent.prototype, "options", {
        get: function () {
            var src = this.properties.itemsSource;
            if (Array.isArray(src)) {
                return src;
            }
            if (typeof src === 'string' && src.startsWith('$.')) {
                return JSONUtils.find(this.dataModel, src);
            }
        },
        enumerable: false,
        configurable: true
    });
    SelectComponent.decorators = [
        { type: Component, args: [{
                    selector: 'dc-select',
                    template: "\n  <ng-select [items]=\"options\" [ngStyle]=\"selectStyles\"\n      [(ngModel)]=\"componentDataModel\" [bindLabel]=\"properties.bindLabel\"\n      [bindValue]=\"properties.bindValue || 'value'\" [placeholder]=\"properties.placeholder\"\n      (add)=\"emitEvent(properties.add, $event)\"\n      (blur)=\"emitEvent(properties.blur, $event)\"\n      (change)=\"onSelect()\"\n      (close)=\"emitEvent(properties.close, $event)\"\n      (clear)=\"emitEvent(properties.clear, $event)\"\n      (focus)=\"emitEvent(properties.focus, $event)\"\n      (search)=\"emitEvent(properties.search, $event)\"\n      (open)=\"emitEvent(properties.open, $event)\"\n      (remove)=\"emitEvent(properties.remove, $event)\"\n      (scroll)=\"emitEvent(properties.scroll, $event)\"\n      (scrollToEnd)=\"emitEvent(properties.scrollToEnd, $event)\"></ng-select>\n    ",
                    styles: ["\n    :host ::ng-deep .ng-select.ng-select-single .ng-select-container {\n      height: inherit;\n      min-height: 30px;\n    }\n  "]
                },] }
    ];
    return SelectComponent;
}(BaseUIComponent));
var SelectProperties = /** @class */ (function (_super) {
    __extends(SelectProperties, _super);
    function SelectProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Select options or binding to dataModel.',
            example: '[{label: "One", value: 1}]',
        }),
        __metadata("design:type", Object)
    ], SelectProperties.prototype, "itemsSource", void 0);
    __decorate([
        propDescription({
            description: 'Select height.',
            example: '30px',
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "selectHeight", void 0);
    __decorate([
        propDescription({
            description: 'Placeholder',
            example: 'Select name',
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "placeholder", void 0);
    __decorate([
        propDescription({
            description: 'Label property.',
            example: 'name',
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "bindLabel", void 0);
    __decorate([
        propDescription({
            description: 'Value property.',
            example: 'id',
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "bindValue", void 0);
    __decorate([
        propDescription({
            description: 'Allows to select multiple items.',
            example: 'true'
        }),
        __metadata("design:type", Boolean)
    ], SelectProperties.prototype, "multiple", void 0);
    __decorate([
        propDescription({
            description: 'Output add event handler.',
            example: 'onAdd()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "add", void 0);
    __decorate([
        propDescription({
            description: 'Output blur event handler.',
            example: 'onBlur()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "blur", void 0);
    __decorate([
        propDescription({
            description: 'Output change event handler.',
            example: 'onChange()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "change", void 0);
    __decorate([
        propDescription({
            description: 'Output close event handler.',
            example: 'onClose()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "close", void 0);
    __decorate([
        propDescription({
            description: 'Output clear event handler.',
            example: 'onClear()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "clear", void 0);
    __decorate([
        propDescription({
            description: 'Output focus event handler.',
            example: 'onFocus()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "focus", void 0);
    __decorate([
        propDescription({
            description: 'Output search event handler.',
            example: 'onSearch()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "search", void 0);
    __decorate([
        propDescription({
            description: 'Output open event handler.',
            example: 'onOpen()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "open", void 0);
    __decorate([
        propDescription({
            description: 'Output remove event handler.',
            example: 'onRemove()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "remove", void 0);
    __decorate([
        propDescription({
            description: 'Output scroll event handler.',
            example: 'onScroll()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "scroll", void 0);
    __decorate([
        propDescription({
            description: 'Output scrollToEnd event handler.',
            example: 'onScrollToEnd()',
            type: PropTypes.EVENT
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "scrollToEnd", void 0);
    return SelectProperties;
}(BindingProperties));
var selectDescriptor = {
    name: 'ng-select',
    label: 'UI Select Input',
    packageName: packageName,
    category: "Basic" /* Basic */,
    description: 'NG Select component',
    itemProperties: SelectProperties,
    component: SelectComponent,
    example: example,
    parseUIModel: function (xmlRes) {
        var itemProperties = {};
        if (!xmlRes.attrs.itemsSource && xmlRes.childNodes) {
            itemProperties.itemsSource = xmlRes.childNodes.map(function (r) {
                return { label: r._, value: r.$ && r.$.hasOwnProperty('value') ? r.$.value : r._ };
            });
            xmlRes.childNodes = null;
        }
        itemProperties.multiple = xmlRes.attrs.multiple === 'true';
        return {
            type: 'ng-select',
            itemProperties: itemProperties
        };
    },
    defaultModel: "<ng-select width=\"100px\" itemsSource=\"$.list\" binding=\"$.value\"></ng-select>",
    propertiesDescriptor: [
        ['selectHeight', { name: 'selectHeight', label: 'Select Height', category: PropertyCategories.Layout }],
    ],
    children: [{
            tag: 'option',
            properties: [{
                    name: 'value',
                    label: 'Option value'
                }]
        }]
};

var TabsComponent = /** @class */ (function (_super) {
    __extends(TabsComponent, _super);
    function TabsComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TabsComponent.decorators = [
        { type: Component, args: [{
                    selector: 'dc-tabs-ui',
                    template: "\n    <tabset class=\"tabset-fx w-100 overflow-auto nav-tabs-boxed\">\n      <tab *ngFor=\"let item of uiModel.children; let i = index\" [heading]=\"item.itemProperties.header || 'Tab ' + (i + 1)\">\n      <dc-ui-selector\n          (changedDataModel)=\"changedDataModel.emit(dataModel)\"\n          (eventHandlers)=\"eventHandlers.emit($event)\"\n          [uiModel]=\"item\"\n          [dataModel]=\"dataModel\"\n          ></dc-ui-selector>\n      </tab>\n    </tabset>\n  "
                },] }
    ];
    return TabsComponent;
}(BaseUIComponent));
var TabsProperties = /** @class */ (function (_super) {
    __extends(TabsProperties, _super);
    function TabsProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return TabsProperties;
}(StyleProperties));
var example$1 = {
    title: 'Tabs group example',
    uiModel: "\n  <tab-container width=\"100%\" height=\"100%\" margin=\"8px\">\n\t\t<tab header=\"Test tab\" padding=\"0.5rem\">\n\t\t\t<text text-style=\"h1\">Tab 1 static text content</text>\n\t\t</tab>\n    <tab header=\"Btn tab\" class=\"align-items-start p-2 flex-column\">\n      <text text-style=\"h1\">Button content</text>\n      <button class=\"btn btn-primary mr-2\" onClick=\"button1_Click\">Click</button>\n      <div>\n        <h4>ClickCount:</h4>\n        <text text-style=\"h4\">$.clickCount</text>\n      </div>\n\t\t</tab>\n\t</tab-container>\n  ",
    scripts: "\n  def button1_Click():\n    print(\"button1_Click\")\n    if dataModel.clickCount == null:\n      dataModel.clickCount = 0\n    dataModel.clickCount = dataModel.clickCount + 1\n  ",
    dataModel: {}
};
var tabsDescriptor = {
    name: 'tab-container',
    label: 'Tabs container (Bootstrap)',
    packageName: packageName,
    category: "Containers" /* Containers */,
    description: 'Tabs component',
    itemProperties: TabsProperties,
    component: TabsComponent,
    example: example$1,
    parseUIModel: function (xmlData) {
        var children = xmlData.childNodes.map(function (child) {
            var itemProperties = child.$;
            itemProperties.height = '100%';
            itemProperties.width = '100%';
            return {
                type: 'section',
                children: child.$$.map(function (r) { return CoreService.getUIModel(toXMLResult(r)); }),
                itemProperties: itemProperties
            };
        });
        return {
            type: 'tab-container',
            children: children
        };
    },
    children: [{
            tag: 'tab',
            hasChildren: true,
            properties: [{
                    name: 'header',
                    label: 'Tab title'
                }]
        }],
    defaultModel: "<tab-container width=\"100%\" height=\"100%\" margin=\"8px\">\n  <tab header=\"Tab 1\" padding=\"0.5rem\">\n    <text text-style=\"h1\">Tab 1 static text content</text>\n  </tab>\n  <tab header=\"Tab 2\" padding=\"0.5rem\">\n    <text text-style=\"h1\">Tab 2 static text content</text>\n  </tab>\n</tab-container>"
};

var COMPONENTS_LIST = [
    tabsDescriptor,
    selectDescriptor
];
// Register components.
function registerComponents() {
    COMPONENTS_LIST.forEach(function (component) { return CoreService.registerComponent(component); });
}
function getCategories() {
    var categories = COMPONENTS_LIST.reduce(function (map, desc) {
        map[desc.category] = map[desc.category] || [];
        map[desc.category].push(desc);
        return map;
    }, {});
    return Object.entries(categories).map(function (_a) {
        var _b = __read(_a, 2), key = _b[0], val = _b[1];
        return {
            name: key,
            components: val,
            packageName: packageName
        };
    });
}

var TabsModuleForRoot = TabsModule.forRoot();
var DynamicComponentsBootstrapModule = /** @class */ (function () {
    function DynamicComponentsBootstrapModule() {
        setTheme('bs4');
        registerComponents();
    }
    DynamicComponentsBootstrapModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [SelectComponent, TabsComponent],
                    imports: [
                        DynamicComponentsCoreModule,
                        CommonModule,
                        FormsModule,
                        NgSelectModule,
                        TabsModuleForRoot
                    ]
                },] }
    ];
    DynamicComponentsBootstrapModule.ctorParameters = function () { return []; };
    return DynamicComponentsBootstrapModule;
}());

/*
 * Public API Surface of bootstrap
 */

/**
 * Generated bundle index. Do not edit.
 */

export { COMPONENTS_LIST, DynamicComponentsBootstrapModule, SelectComponent, TabsComponent, TabsModuleForRoot, getCategories, SelectComponent as ɵa, SelectProperties as ɵb, selectDescriptor as ɵc, TabsComponent as ɵd, TabsProperties as ɵe, example$1 as ɵf, tabsDescriptor as ɵg, packageName as ɵh };
//# sourceMappingURL=ngx-dynamic-components-bootstrap.js.map
